package com.yinet.review.service;

import com.yinet.review.domain.FormReview;
import java.util.List;

/**
 * 评审项目Service接口
 * 
 * @author yinet
 * @date 2020-04-28
 */
public interface IFormReviewService 
{
    /**
     * 查询评审项目
     * 
     * @param id 评审项目ID
     * @return 评审项目
     */
    public FormReview selectFormReviewById(Long id);

    /**
     * 查询评审项目列表
     * 
     * @param formReview 评审项目
     * @return 评审项目集合
     */
    public List<FormReview> selectFormReviewList(FormReview formReview);

    /**
     * 新增评审项目
     * 
     * @param formReview 评审项目
     * @return 结果
     */
    public int insertFormReview(FormReview formReview);

    /**
     * 修改评审项目
     * 
     * @param formReview 评审项目
     * @return 结果
     */
    public int updateFormReview(FormReview formReview);

    /**
     * 批量删除评审项目
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteFormReviewByIds(String ids);

    /**
     * 删除评审项目信息
     * 
     * @param id 评审项目ID
     * @return 结果
     */
    public int deleteFormReviewById(Long id);

    String importFormReviewsList(List<FormReview> formReviewsList, boolean updateSupport);
}
